==> snapd-glib_1.2.orig.tar.xz: snapd-glib-1.2/snapd-glib/snapd-enum-types.c <==

/* Generated data (by glib-mkenums) */

/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#include "config.h"
#include "snapd-enum-types.h"

/* enumerations from "./snapd-client.h" */
#include "./snapd-client.h"

GType
snapd_find_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SNAPD_FIND_FLAGS_NONE, "SNAPD_FIND_FLAGS_NONE", "none" },
        { SNAPD_FIND_FLAGS_MATCH_NAME, "SNAPD_FIND_FLAGS_MATCH_NAME", "match-name" },
        { SNAPD_FIND_FLAGS_SELECT_PRIVATE, "SNAPD_FIND_FLAGS_SELECT_PRIVATE", "select-private" },
        { SNAPD_FIND_FLAGS_SELECT_REFRESH, "SNAPD_FIND_FLAGS_SELECT_REFRESH", "select-refresh" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SnapdFindFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-error.h" */
#include "./snapd-error.h"

GType
snapd_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_ERROR_CONNECTION_FAILED, "SNAPD_ERROR_CONNECTION_FAILED", "connection-failed" },
        { SNAPD_ERROR_WRITE_FAILED, "SNAPD_ERROR_WRITE_FAILED", "write-failed" },
        { SNAPD_ERROR_READ_FAILED, "SNAPD_ERROR_READ_FAILED", "read-failed" },
        { SNAPD_ERROR_BAD_REQUEST, "SNAPD_ERROR_BAD_REQUEST", "bad-request" },
        { SNAPD_ERROR_BAD_RESPONSE, "SNAPD_ERROR_BAD_RESPONSE", "bad-response" },
        { SNAPD_ERROR_AUTH_DATA_REQUIRED, "SNAPD_ERROR_AUTH_DATA_REQUIRED", "auth-data-required" },
        { SNAPD_ERROR_AUTH_DATA_INVALID, "SNAPD_ERROR_AUTH_DATA_INVALID", "auth-data-invalid" },
        { SNAPD_ERROR_TWO_FACTOR_REQUIRED, "SNAPD_ERROR_TWO_FACTOR_REQUIRED", "two-factor-required" },
        { SNAPD_ERROR_TWO_FACTOR_INVALID, "SNAPD_ERROR_TWO_FACTOR_INVALID", "two-factor-invalid" },
        { SNAPD_ERROR_PERMISSION_DENIED, "SNAPD_ERROR_PERMISSION_DENIED", "permission-denied" },
        { SNAPD_ERROR_FAILED, "SNAPD_ERROR_FAILED", "failed" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-snap.h" */
#include "./snapd-snap.h"

GType
snapd_confinement_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_CONFINEMENT_UNKNOWN, "SNAPD_CONFINEMENT_UNKNOWN", "unknown" },
        { SNAPD_CONFINEMENT_STRICT, "SNAPD_CONFINEMENT_STRICT", "strict" },
        { SNAPD_CONFINEMENT_DEVMODE, "SNAPD_CONFINEMENT_DEVMODE", "devmode" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdConfinement"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_TYPE_UNKNOWN, "SNAPD_SNAP_TYPE_UNKNOWN", "unknown" },
        { SNAPD_SNAP_TYPE_APP, "SNAPD_SNAP_TYPE_APP", "app" },
        { SNAPD_SNAP_TYPE_KERNEL, "SNAPD_SNAP_TYPE_KERNEL", "kernel" },
        { SNAPD_SNAP_TYPE_GADGET, "SNAPD_SNAP_TYPE_GADGET", "gadget" },
        { SNAPD_SNAP_TYPE_OS, "SNAPD_SNAP_TYPE_OS", "os" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_status_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_STATUS_UNKNOWN, "SNAPD_SNAP_STATUS_UNKNOWN", "unknown" },
        { SNAPD_SNAP_STATUS_AVAILABLE, "SNAPD_SNAP_STATUS_AVAILABLE", "available" },
        { SNAPD_SNAP_STATUS_PRICED, "SNAPD_SNAP_STATUS_PRICED", "priced" },
        { SNAPD_SNAP_STATUS_INSTALLED, "SNAPD_SNAP_STATUS_INSTALLED", "installed" },
        { SNAPD_SNAP_STATUS_ACTIVE, "SNAPD_SNAP_STATUS_ACTIVE", "active" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapStatus"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* Generated data ends here */

==> snapd-glib_1.9.orig.tar.xz: snapd-glib-1.9/snapd-glib/snapd-enum-types.c <==

/* Generated data (by glib-mkenums) */

/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#include "config.h"
#include "snapd-enum-types.h"

/* enumerations from "./snapd-alias.h" */
#include "./snapd-alias.h"

GType
snapd_alias_status_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_ALIAS_STATUS_UNKNOWN, "SNAPD_ALIAS_STATUS_UNKNOWN", "unknown" },
        { SNAPD_ALIAS_STATUS_DEFAULT, "SNAPD_ALIAS_STATUS_DEFAULT", "default" },
        { SNAPD_ALIAS_STATUS_ENABLED, "SNAPD_ALIAS_STATUS_ENABLED", "enabled" },
        { SNAPD_ALIAS_STATUS_DISABLED, "SNAPD_ALIAS_STATUS_DISABLED", "disabled" },
        { SNAPD_ALIAS_STATUS_AUTO, "SNAPD_ALIAS_STATUS_AUTO", "auto" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdAliasStatus"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-app.h" */
#include "./snapd-app.h"

GType
snapd_daemon_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_DAEMON_TYPE_NONE, "SNAPD_DAEMON_TYPE_NONE", "none" },
        { SNAPD_DAEMON_TYPE_UNKNOWN, "SNAPD_DAEMON_TYPE_UNKNOWN", "unknown" },
        { SNAPD_DAEMON_TYPE_SIMPLE, "SNAPD_DAEMON_TYPE_SIMPLE", "simple" },
        { SNAPD_DAEMON_TYPE_FORKING, "SNAPD_DAEMON_TYPE_FORKING", "forking" },
        { SNAPD_DAEMON_TYPE_ONESHOT, "SNAPD_DAEMON_TYPE_ONESHOT", "oneshot" },
        { SNAPD_DAEMON_TYPE_DBUS, "SNAPD_DAEMON_TYPE_DBUS", "dbus" },
        { SNAPD_DAEMON_TYPE_NOTIFY, "SNAPD_DAEMON_TYPE_NOTIFY", "notify" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdDaemonType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-client.h" */
#include "./snapd-client.h"

GType
snapd_find_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SNAPD_FIND_FLAGS_NONE, "SNAPD_FIND_FLAGS_NONE", "none" },
        { SNAPD_FIND_FLAGS_MATCH_NAME, "SNAPD_FIND_FLAGS_MATCH_NAME", "match-name" },
        { SNAPD_FIND_FLAGS_SELECT_PRIVATE, "SNAPD_FIND_FLAGS_SELECT_PRIVATE", "select-private" },
        { SNAPD_FIND_FLAGS_SELECT_REFRESH, "SNAPD_FIND_FLAGS_SELECT_REFRESH", "select-refresh" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SnapdFindFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_install_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SNAPD_INSTALL_FLAGS_NONE, "SNAPD_INSTALL_FLAGS_NONE", "none" },
        { SNAPD_INSTALL_FLAGS_CLASSIC, "SNAPD_INSTALL_FLAGS_CLASSIC", "classic" },
        { SNAPD_INSTALL_FLAGS_DANGEROUS, "SNAPD_INSTALL_FLAGS_DANGEROUS", "dangerous" },
        { SNAPD_INSTALL_FLAGS_DEVMODE, "SNAPD_INSTALL_FLAGS_DEVMODE", "devmode" },
        { SNAPD_INSTALL_FLAGS_JAILMODE, "SNAPD_INSTALL_FLAGS_JAILMODE", "jailmode" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SnapdInstallFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_create_user_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SNAPD_CREATE_USER_FLAGS_NONE, "SNAPD_CREATE_USER_FLAGS_NONE", "none" },
        { SNAPD_CREATE_USER_FLAGS_SUDO, "SNAPD_CREATE_USER_FLAGS_SUDO", "sudo" },
        { SNAPD_CREATE_USER_FLAGS_KNOWN, "SNAPD_CREATE_USER_FLAGS_KNOWN", "known" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SnapdCreateUserFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-error.h" */
#include "./snapd-error.h"

GType
snapd_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_ERROR_CONNECTION_FAILED, "SNAPD_ERROR_CONNECTION_FAILED", "connection-failed" },
        { SNAPD_ERROR_WRITE_FAILED, "SNAPD_ERROR_WRITE_FAILED", "write-failed" },
        { SNAPD_ERROR_READ_FAILED, "SNAPD_ERROR_READ_FAILED", "read-failed" },
        { SNAPD_ERROR_BAD_REQUEST, "SNAPD_ERROR_BAD_REQUEST", "bad-request" },
        { SNAPD_ERROR_BAD_RESPONSE, "SNAPD_ERROR_BAD_RESPONSE", "bad-response" },
        { SNAPD_ERROR_AUTH_DATA_REQUIRED, "SNAPD_ERROR_AUTH_DATA_REQUIRED", "auth-data-required" },
        { SNAPD_ERROR_AUTH_DATA_INVALID, "SNAPD_ERROR_AUTH_DATA_INVALID", "auth-data-invalid" },
        { SNAPD_ERROR_TWO_FACTOR_REQUIRED, "SNAPD_ERROR_TWO_FACTOR_REQUIRED", "two-factor-required" },
        { SNAPD_ERROR_TWO_FACTOR_INVALID, "SNAPD_ERROR_TWO_FACTOR_INVALID", "two-factor-invalid" },
        { SNAPD_ERROR_PERMISSION_DENIED, "SNAPD_ERROR_PERMISSION_DENIED", "permission-denied" },
        { SNAPD_ERROR_FAILED, "SNAPD_ERROR_FAILED", "failed" },
        { SNAPD_ERROR_TERMS_NOT_ACCEPTED, "SNAPD_ERROR_TERMS_NOT_ACCEPTED", "terms-not-accepted" },
        { SNAPD_ERROR_PAYMENT_NOT_SETUP, "SNAPD_ERROR_PAYMENT_NOT_SETUP", "payment-not-setup" },
        { SNAPD_ERROR_PAYMENT_DECLINED, "SNAPD_ERROR_PAYMENT_DECLINED", "payment-declined" },
        { SNAPD_ERROR_ALREADY_INSTALLED, "SNAPD_ERROR_ALREADY_INSTALLED", "already-installed" },
        { SNAPD_ERROR_NOT_INSTALLED, "SNAPD_ERROR_NOT_INSTALLED", "not-installed" },
        { SNAPD_ERROR_NO_UPDATE_AVAILABLE, "SNAPD_ERROR_NO_UPDATE_AVAILABLE", "no-update-available" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-snap.h" */
#include "./snapd-snap.h"

GType
snapd_confinement_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_CONFINEMENT_UNKNOWN, "SNAPD_CONFINEMENT_UNKNOWN", "unknown" },
        { SNAPD_CONFINEMENT_STRICT, "SNAPD_CONFINEMENT_STRICT", "strict" },
        { SNAPD_CONFINEMENT_DEVMODE, "SNAPD_CONFINEMENT_DEVMODE", "devmode" },
        { SNAPD_CONFINEMENT_CLASSIC, "SNAPD_CONFINEMENT_CLASSIC", "classic" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdConfinement"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_TYPE_UNKNOWN, "SNAPD_SNAP_TYPE_UNKNOWN", "unknown" },
        { SNAPD_SNAP_TYPE_APP, "SNAPD_SNAP_TYPE_APP", "app" },
        { SNAPD_SNAP_TYPE_KERNEL, "SNAPD_SNAP_TYPE_KERNEL", "kernel" },
        { SNAPD_SNAP_TYPE_GADGET, "SNAPD_SNAP_TYPE_GADGET", "gadget" },
        { SNAPD_SNAP_TYPE_OS, "SNAPD_SNAP_TYPE_OS", "os" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_status_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_STATUS_UNKNOWN, "SNAPD_SNAP_STATUS_UNKNOWN", "unknown" },
        { SNAPD_SNAP_STATUS_AVAILABLE, "SNAPD_SNAP_STATUS_AVAILABLE", "available" },
        { SNAPD_SNAP_STATUS_PRICED, "SNAPD_SNAP_STATUS_PRICED", "priced" },
        { SNAPD_SNAP_STATUS_INSTALLED, "SNAPD_SNAP_STATUS_INSTALLED", "installed" },
        { SNAPD_SNAP_STATUS_ACTIVE, "SNAPD_SNAP_STATUS_ACTIVE", "active" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapStatus"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* Generated data ends here */
